@@ -10,10 +10,11 @@ from cqh_file.utils import get_md5
 
 
 class ClientLoop(object):
-    def __init__(self, url, dir, sleep):
+    def __init__(self, url, dir, sleep, delete):
         self.url = url
         self.dir = dir
         self.sleep = sleep
+        self.delete = delete
         self.session = requests.Session()
 
     def path_url(self, url_path):
@@ -57,8 +58,18 @@ class ClientLoop(object):
             click.echo("="*80)
             click.echo("sleep {}, {}".format(self.sleep, datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")))
             time.sleep(self.sleep)
+    
+    def try_delete(self):
+        if not self.delete:
+            return
+        for name in os.listdir(self.dir):
+            file_path = os.path.join(self.dir, name)
+            if os.path.isfile(name):
+                os.remove(file_path)
+                click.echo("delete name: [{}]".format(name))
 
     def run_once(self):
+        self.try_delete()
         j = self.read_serve_list()
         client_d = self.read_client_md5_value()
         # 遍历所有的名字,检查需不需要下载,然后下载就好了
