@@ -28,12 +28,14 @@ def serve(port, dir, timeout):
 @click.option("--url")
 @click.option("--dir")
 @click.option("--sleep", default=300)
-def client(url, dir, sleep):
-    click.echo("url:{}, dir:{}, sleep:{}".format(url,dir, sleep))
+@click.option("--delete", default=1)
+def client(url, dir, sleep, delete):
+    click.echo("url:{}, dir:{}, sleep:{}, delete:{}".format(url,dir, sleep, delete))
     from cqh_file import __version__
     click.echo("version:{}".format(__version__))
     from cqh_file.client import ClientLoop
-    loop = ClientLoop(url=url, dir=dir, sleep=sleep)
+    loop = ClientLoop(url=url, dir=dir, sleep=sleep, 
+    delete=delete)
     loop.loop()
 
 cli.add_command(serve)
